context("canvasXpress Web Charts - Scatter2D")


test_that("cXscatter2d1", {
    check_ui_test(cXscatter2d1())
})

test_that("cXscatter2d2", {
    check_ui_test(cXscatter2d2())

    warning("Names are different, web example uses var, not V")
})

test_that("cXscatter2d3", {
    check_ui_test(cXscatter2d3())
})

test_that("cXscatter2d4", {
    check_ui_test(cXscatter2d4())

    message("Some legends boxes may not be visible if plot is not resized due to space allotted - working as designed")
})

test_that("cXscatter2d5", {
    check_ui_test(cXscatter2d5())
})

test_that("cXscatter2d6", {
    check_ui_test(cXscatter2d6())
})

test_that("cXscatter2d7", {
    check_ui_test(cXscatter2d7())

    message("Some legends boxes may not be visible if plot is not resized due to space allotted - working as designed")
})

test_that("cXscatter2d8", {
    check_ui_test(cXscatter2d8())
})

test_that("cXscatter2d9", {
    check_ui_test(cXscatter2d9())
})

test_that("cXscatter2d10", {
    check_ui_test(cXscatter2d10())
})

test_that("cXscatter2d11", {
    check_ui_test(cXscatter2d11())
})

test_that("cXscatter2d12", {
    check_ui_test(cXscatter2d12())
})

test_that("cXscatter2d13", {
    check_ui_test(cXscatter2d13())
})

test_that("cXscatter2d14", {
    check_ui_test(cXscatter2d14())
})

test_that("cXscatter2d15", {
    check_ui_test(cXscatter2d15())
})

test_that("cXscatter2d16", {
    check_ui_test(cXscatter2d16())
})

test_that("cXscatter2d17", {
    check_ui_test(cXscatter2d17())
})

test_that("cXscatter2d18", {
    check_ui_test(cXscatter2d18())
})
